@@ -288,6 +288,7 @@ class CroniterTest(base.TestCase):
         self.assertRaises(ValueError, croniter, '-90 * * * *')
         self.assertRaises(ValueError, croniter, 'a * * * *')
         self.assertRaises(ValueError, croniter, '* * * janu-jun *')
+        self.assertRaises(CroniterBadCronError, croniter, "0-1& * * * *", datetime.now())
 
     def testSundayToThursdayWithAlphaConversion(self):
         base = datetime(2010, 8, 25, 15, 56)  # wednesday
@@ -1285,7 +1286,7 @@ class CroniterRangeTest(base.TestCase):
         with self.assertRaises(StopIteration):
             next(iterable)
 
-    def test_isssue151(self):
+    def test_issue151(self):
         """."""
         self.assertTrue(
             croniter.match("* * * * *", datetime(2019, 1, 14, 11, 0, 59, 999999)))
